@@ -3,17 +3,77 @@ import warnings
 
 import sheraf.exceptions
 from sheraf.models.base import BaseModel, BaseModelMetaclass
-from sheraf.models.indexmanager import SimpleIndexManager, MultipleDatabaseIndexManager
+from sheraf.models.indexmanager import (
+    IndexManager,
+    SimpleIndexManager,
+    MultipleDatabaseIndexManager,
+)
 
 
-class BaseIndexedModel(BaseModel, metaclass=BaseModelMetaclass):
+class BaseIndexedModelMetaclass(BaseModelMetaclass):
+    def __new__(cls, name, bases, attrs):
+        klass = super().__new__(cls, name, bases, attrs)
+        klass.indexes = {}
+
+        def add_index(name, index, attributes, add_to_attribute=True):
+            # Get the real attributes objects when string have been passed as attributes
+            # in the index.
+
+            if not index.attributes:
+                raise sheraf.exceptions.SherafException(
+                    f"The {index.key} must have at least one attribute."
+                )
+
+            new_attrs = []
+            for a in index.attributes:
+                if isinstance(a, str):
+                    try:
+                        a = attributes[a]
+                    except KeyError:
+                        raise sheraf.exceptions.SherafException(
+                            f"The {index.key} index has a wrong attribute with name '{a}'."
+                        )
+                if not isinstance(a, sheraf.BaseAttribute):
+                    raise sheraf.exceptions.SherafException(
+                        f"The {index.key} index has a wrong attribute."
+                    )
+
+                new_attrs.append(a)
+            index.attributes = new_attrs
+
+            index.attribute_values_func = {
+                attributes[k] if isinstance(k, str) else k: v
+                for k, v in index.attribute_values_func.items()
+            }
+
+            index.key = index.key or name
+
+            for attribute in index.attributes:
+
+                if add_to_attribute:
+                    attribute.indexes[index.key] = index
+
+                attribute.lazy = False
+            klass.indexes[index.key] = klass.index_manager(index)
+
+        for name, index in attrs.items():
+            if isinstance(index, sheraf.attributes.index.Index):
+                add_index(name, index, klass.attributes)
+
+        for attribute in klass.attributes.values():
+            for index_key, index in attribute.indexes.items():
+                add_index(attribute.key(klass), index, klass.attributes, False)
+
+        return klass
+
+
+class BaseIndexedModel(BaseModel, metaclass=BaseIndexedModelMetaclass):
     """
     This class handles the whole indexation mechanism. The mechanisms
     for reading or iterating over models in the database are handled
     here.
     """
 
-    _indexes = None
     _primary_key = None
     _is_first_instance = None
 
@@ -21,21 +81,10 @@ class BaseIndexedModel(BaseModel, metaclass=BaseModelMetaclass):
         self._identifier = None
         super().__init__(*args, **kwargs)
 
-    @classmethod
-    def indexes(cls):
-        if cls._indexes is None:
-            cls._indexes = {}
-            for attribute_name, attribute in cls.attributes.items():
-                for index_key, index in attribute.indexes.items():
-                    index.key = index_key or attribute.key(cls)
-                    cls._indexes[index.key] = cls.index_manager(index)
-
-        return cls._indexes
-
     @classmethod
     def primary_key(cls):
         if cls._primary_key is None:
-            for index_name, index in cls.indexes().items():
+            for index_name, index in cls.indexes.items():
                 if not index.details.primary:
                     continue
 
@@ -45,9 +94,7 @@ class BaseIndexedModel(BaseModel, metaclass=BaseModelMetaclass):
                 else:
                     raise sheraf.exceptions.PrimaryKeyException(
                         "A model can have only one primary key. '{}' has '{}' and '{}'".format(
-                            cls.__class__.__name__,
-                            cls._primary_key,
-                            index_name,
+                            cls.__class__.__name__, cls._primary_key, index_name,
                         )
                     )
 
@@ -87,7 +134,7 @@ class BaseIndexedModel(BaseModel, metaclass=BaseModelMetaclass):
             index_name, key = list(kwargs.items())[0]
 
         try:
-            index = cls.indexes()[index_name]
+            index = cls.indexes[index_name]
         except KeyError:
             raise sheraf.exceptions.InvalidIndexException(
                 "'{}' is not a valid index".format(index_name)
@@ -249,11 +296,11 @@ class BaseIndexedModel(BaseModel, metaclass=BaseModelMetaclass):
                             resetted.
         """
         if not index_names:
-            indexes = cls.indexes().values()
+            indexes = cls.indexes.values()
         else:
             indexes = [
                 index
-                for index_name, index in cls.indexes().items()
+                for index_name, index in cls.indexes.items()
                 if index_name in index_names
             ]
 
@@ -356,10 +403,54 @@ class BaseIndexedModel(BaseModel, metaclass=BaseModelMetaclass):
     def __setattr__(self, name, value):
         attribute = self.attributes.get(name)
         if attribute:
-            self.update_attribute_indexes(attribute, value)
+            old_values = self.before_index_edition(attribute)
 
         super().__setattr__(name, value)
 
+        if attribute:
+            self.after_index_edition(attribute, old_values)
+
+    def __delattr__(self, name):
+        attribute = self.attributes.get(name)
+        if attribute:
+            old_values = self.before_index_edition(attribute)
+
+        super().__delattr__(name)
+
+        if attribute:
+            self.after_index_edition(attribute, old_values)
+
+    def before_index_edition(self, attribute):
+        old_index_values = {}
+        for index in attribute.indexes.values():
+            if not self._is_indexable(index):
+                warnings.warn(
+                    "New index in an already populated table. %s.%s will not be indexed. "
+                    'Consider calling %s.index_table_rebuild(["%s"]) to initialize the indexation table.'
+                    % (
+                        self.__class__.__name__,
+                        index.key,
+                        self.__class__.__name__,
+                        index.key,
+                    ),
+                    sheraf.exceptions.IndexationWarning,
+                    stacklevel=5,
+                )
+                continue
+
+            old_index_values[index] = index.get_model_values(self)
+        return old_index_values
+
+    def after_index_edition(self, attribute, old_index_values):
+        for index in attribute.indexes.values():
+            if not self._is_indexable(index):
+                continue
+
+            new_index_values = index.get_model_values(self)
+
+            index_manager = self.indexes[index.key]
+            index_manager.update_item(self, old_index_values[index], new_index_values)
+
     @property
     def identifier(self):
         """
@@ -380,33 +471,10 @@ class BaseIndexedModel(BaseModel, metaclass=BaseModelMetaclass):
         if self._is_first_instance is None:
             self._is_first_instance = not self.index_manager().initialized()
 
-        index_manager = self.indexes()[index.key]
+        index_manager = self.indexes[index.key]
         index_table_exists = index_manager.table_initialized()
         return self._is_first_instance or index_table_exists
 
-    def update_attribute_indexes(self, attribute, value):
-        for index in attribute.indexes.values():
-            if not self._is_indexable(index):
-                warnings.warn(
-                    "New index in an already populated table. %s.%s will not be indexed. "
-                    'Consider calling %s.index_table_rebuild(["%s"]) to initialize the indexation table.'
-                    % (
-                        self.__class__.__name__,
-                        index.key,
-                        self.__class__.__name__,
-                        index.key,
-                    ),
-                    sheraf.exceptions.IndexationWarning,
-                    stacklevel=5,
-                )
-                continue
-
-            index_manager = self.indexes()[index.key]
-            if attribute.is_created(self):
-                index_manager.update_item(self, attribute.read(self), value)
-            else:
-                index_manager.add_item(self, index.get_values(keys=value))
-
     def copy(self, **kwargs):
         r"""
         Copies a model.
@@ -421,8 +489,9 @@ class BaseIndexedModel(BaseModel, metaclass=BaseModelMetaclass):
         """
 
         unique_attributes = (
-            index.details.attribute
-            for index in self.indexes().values()
+            attribute
+            for index in self.indexes.values()
+            for attribute in index.details.attributes
             if index.details.unique
         )
 
@@ -446,7 +515,7 @@ class BaseIndexedModel(BaseModel, metaclass=BaseModelMetaclass):
             ...
         sheraf.exceptions.ModelObjectNotFoundException: Id '...' not found in MyModel
         """
-        for index in self.indexes().values():
+        for index in self.indexes.values():
             index.delete_item(self)
 
         for attr in self.attributes.values():
@@ -454,10 +523,10 @@ class BaseIndexedModel(BaseModel, metaclass=BaseModelMetaclass):
 
     @classmethod
     def count(cls):
-        return cls.indexes()[cls.primary_key()].count()
+        return cls.indexes[cls.primary_key()].count()
 
 
-class IndexedModelMetaclass(BaseModelMetaclass):
+class IndexedModelMetaclass(BaseIndexedModelMetaclass):
     """
     Contains the mapping of tables (name of models) to their
     corresponding model definitions
@@ -538,7 +607,7 @@ class IndexedModel(BaseIndexedModel, metaclass=IndexedModelMetaclass):
         return super().create(*args, **kwargs)
 
 
-class SimpleIndexedModel(BaseIndexedModel):
+class SimpleIndexedModel(BaseIndexedModel, metaclass=BaseIndexedModelMetaclass):
     @classmethod
     def index_manager(cls, index=None):
         return SimpleIndexManager(index)
