@@ -19,8 +19,8 @@ class IndexManager:
                      the current values of the index for the current model
                      are set.
         """
-        if not keys:
-            keys = self.details.get_values(model)
+        if keys is None:
+            keys = self.details.get_model_values(model)
 
         table = self.table()
 
@@ -39,8 +39,8 @@ class IndexManager:
                      the current values of the index for the current model
                      are removed.
         """
-        if not keys:
-            keys = self.details.get_values(model)
+        if keys is None:
+            keys = self.details.get_model_values(model)
 
         table = self.table()
 
@@ -53,22 +53,22 @@ class IndexManager:
             else:
                 self._table_del_multiple(table, key, model.mapping)
 
-    def update_item(self, item, old_keys, new_keys):
-        old_values = self.details.get_values(keys=old_keys)
-        new_values = self.details.get_values(keys=new_keys)
-
-        if old_keys and new_keys:
+    def update_item(self, model, old_values, new_values):
+        if old_values and new_values:
             del_values = old_values - new_values
             add_values = new_values - old_values
 
-            self.delete_item(item, del_values)
-            self.add_item(item, add_values)
+            if del_values:
+                self.delete_item(model, del_values)
 
-        elif not old_keys:
-            self.add_item(item, new_values)
+            if add_values:
+                self.add_item(model, add_values)
 
-        elif not new_keys:
-            self.delete_item(item, old_values)
+        elif not old_values:
+            self.add_item(model, new_values)
+
+        elif not new_values:
+            self.delete_item(model, old_values)
 
     def _table_del_unique(self, table, key, value):
         del table[key]
