@@ -73,11 +73,13 @@ def attempt(
         try:
             connection.transaction_manager.begin()
             _response = function(*args, **kwargs)
+
             if commit():
                 start_commit_time = time.time()
                 connection.transaction_manager.commit()
             else:
                 connection.transaction_manager.abort()
+
             return _response
 
         except exception_classes as exc:
@@ -125,7 +127,7 @@ def attempt(
     raise _exc
 
 
-def commit(f):
+def commit(f=None):
     """
     Wrapper shortcut for :func:`~sheraf.transactions.attempt`.
 
@@ -149,6 +151,12 @@ def commit(f):
     True
     """
 
+    if f is None:
+        connection = sheraf.Database.current_connection()
+        if not connection:
+            raise sheraf.exceptions.NotConnectedException()
+        connection.transaction_manager.commit()
+
     @functools.wraps(f)
     def wrapper(*args, **kwargs):
         return attempt(f, args=args, kwargs=kwargs)
